@@ -3,7 +3,9 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
+from ncbi.datasets.openapi.api.dataset_download_api import DatasetDownloadApi
 from ncbi.datasets.openapi.api.gene_api import GeneApi
 from ncbi.datasets.openapi.api.genome_api import GenomeApi
+from ncbi.datasets.openapi.api.prokaryote_api import ProkaryoteApi
 from ncbi.datasets.openapi.api.version_api import VersionApi
 from ncbi.datasets.openapi.api.virus_api import VirusApi
